@@ -9,7 +9,7 @@
 //! Ensure [`std::mem::drop`](http://doc.rust-lang.org/1.56.0/std/mem/fn.drop.html) does in fact drop:
 //!
 //! ```
-//! use droptest::{DropRegistry, assert_drop};
+//! use droptest::prelude::*;
 //!
 //! let registry = DropRegistry::default();
 //! let guard = registry.new_guard();
@@ -22,7 +22,7 @@
 //! Ensure [`std::mem::forget`](https://doc.rust-lang.org/stable/std/mem/fn.forget.html) does not drop:
 //!
 //! ```
-//! use droptest::{DropRegistry, assert_no_drop};
+//! use droptest::prelude::*;
 //!
 //! let registry = DropRegistry::default();
 //! let guard = registry.new_guard();
@@ -36,7 +36,7 @@
 //! only drops the when reference count reaches `0`:
 //!
 //! ```
-//! use droptest::{DropRegistry, assert_drop, assert_no_drop};
+//! use droptest::prelude::*;
 //!
 //! let registry = DropRegistry::default();
 //! let guard = registry.new_guard();
@@ -59,37 +59,101 @@ use std::{
     sync::Mutex,
 };
 
+/// The doptest prelude.
 pub mod prelude {
     pub use super::{
-        assert_drop, assert_no_drop, DropGuard, DropGuardId, DropRegistry, DropStatistics,
+        assert_drop, assert_drop_stats, assert_no_drop, DropGuard, DropGuardId, DropRegistry,
+        DropStatistics,
     };
 }
 
-// TODO(regexident): remove in ">= v0.2.0".
-#[deprecated(note = "please use `DropStatistics` instead")]
-pub use DropStatistics as Statistics;
-
-// TODO(regexident): remove in ">= v0.2.0".
-#[deprecated(note = "please use `DropGuardId` instead")]
-pub use DropGuardId as DropId;
-
+/// Asserts that the registry has registered a drop for the given id.
+///
+/// Like assert!, this macro has a second form, where a custom panic message can be provided.
+///
+/// # Examples
+/// ```
+/// use droptest::prelude::*;
+///
+/// let registry = DropRegistry::default();
+/// let guard = registry.new_guard();
+/// let id = guard.id();
+///
+/// std::mem::drop(guard);
+///
+/// assert_drop!(registry, id);
+/// // or:
+/// assert_drop!(registry, id, "an optional message");
+/// ```
 #[macro_export]
 macro_rules! assert_drop {
     ($registry:expr, $guard_id:expr) => {
-        assert!($registry.is_dropped($guard_id), "expected drop.");
+        assert!($registry.is_dropped($guard_id), "expected drop for {:?}.", $guard_id);
     };
     ($registry:expr, $guard_id:expr $(,$message:tt)+) => {
-        assert!($registry.is_dropped($guard_id), "expected drop: {}", format!($($message)+));
+        assert!($registry.is_dropped($guard_id), "expected drop for {:?}: {}", $guard_id, format!($($message)+));
     };
 }
 
+/// Asserts that the registry has not registered a drop for the given id.
+///
+/// Like assert!, this macro has a second form, where a custom panic message can be provided.
+///
+/// # Examples
+/// ```
+/// use droptest::prelude::*;
+///
+/// let registry = DropRegistry::default();
+/// let guard = registry.new_guard();
+/// let id = guard.id();
+///
+/// assert_no_drop!(registry, id);
+/// // or:
+/// assert_no_drop!(registry, id, "an optional message");
+/// ```
 #[macro_export]
 macro_rules! assert_no_drop {
     ($registry:expr, $guard_id:expr) => {
-        assert!(!$registry.is_dropped($guard_id), "expected no drop.");
+        assert!(!$registry.is_dropped($guard_id), "expected no drop for {:?}.", $guard_id);
     };
     ($registry:expr, $guard_id:expr $(,$message:tt)*) => {
-        assert!(!$registry.is_dropped($guard_id), "expected no drop: {}", format!($($message)+));
+        assert!(!$registry.is_dropped($guard_id), "expected no drop for {:?}: {}", $guard_id, format!($($message)+));
+    };
+}
+
+/// Asserts that the registry's current stats match the provided pattern.
+///
+/// Like assert!, this macro has a second form, where a custom panic message can be provided.
+///
+/// # Examples
+/// ```
+/// use droptest::prelude::*;
+///
+/// let registry = DropRegistry::default();
+/// let guard = registry.new_guard();
+/// let id = guard.id();
+///
+/// assert_drop_stats!(registry, { created: 1 });
+/// // or:
+/// assert_drop_stats!(registry, { dropped: 0 });
+/// // or:
+/// assert_drop_stats!(registry, { created: 1, dropped: 0 });
+/// // or:
+/// assert_drop_stats!(registry, { created: 1, dropped: 0 }, "an optional message");
+/// ```
+#[macro_export]
+macro_rules! assert_drop_stats {
+    ($registry:expr, { $($field:ident: $expected:expr),+ }) => {
+        assert!(matches!($registry.stats(), $crate::DropStatistics {
+            $($field: $expected,)*
+            ..
+        }), concat!("expected {{ ", stringify!($($field: $expected),*), " }}"));
+    };
+    ($registry:expr, { $($field:ident: $expected:expr),+ } $(,$message:tt)*) => {
+        assert!(matches!($registry.stats(), $crate::DropStatistics {
+            $($field: $expected,)*
+            ..
+        }), concat!("expected {{ ", stringify!($($field: $expected),*), " }}: {}"), format!($($message)+));
     };
 }
 
@@ -111,7 +175,7 @@ impl<'a> DropGuardId<'a> {
 
 impl<'a> fmt::Debug for DropGuardId<'a> {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        self.value.fmt(f)
+        f.debug_tuple("DropGuardId").field(&self.value).finish()
     }
 }
 
@@ -127,7 +191,7 @@ impl<'a, T> DropGuard<'a, T> {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard();
@@ -144,7 +208,7 @@ impl<'a, T> DropGuard<'a, T> {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard_for(42);
@@ -161,7 +225,7 @@ impl<'a, T> DropGuard<'a, T> {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let (id, guard) = registry.new_guard_for(42).by_id();
@@ -177,7 +241,7 @@ impl<'a, T> DropGuard<'a, T> {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard();
@@ -285,7 +349,7 @@ impl DropRegistry {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard_for(42);
@@ -312,7 +376,7 @@ impl DropRegistry {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard();
@@ -329,7 +393,7 @@ impl DropRegistry {
     ///
     /// # Examples
     /// ```
-    /// use droptest::{DropRegistry, assert_no_drop, DropStatistics};
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard();
@@ -357,7 +421,7 @@ impl DropRegistry {
     ///
     /// # Examples
     /// ```
-    /// use droptest::DropRegistry;
+    /// use droptest::prelude::*;
     ///
     /// let registry = DropRegistry::default();
     /// let guard = registry.new_guard();
@@ -394,33 +458,15 @@ mod tests {
     fn it_works() {
         let registry = DropRegistry::default();
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 0,
-                dropped: 0
-            }
-        );
+        assert_drop_stats!(registry, { created: 0, dropped: 0 });
 
         let guard = registry.new_guard_for(42);
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 1,
-                dropped: 0
-            }
-        );
+        assert_drop_stats!(registry, { created: 1, dropped: 0 });
 
         std::mem::drop(guard);
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 1,
-                dropped: 1
-            }
-        );
+        assert_drop_stats!(registry, { created: 1, dropped: 1 });
     }
 
     #[test]
@@ -463,61 +509,29 @@ mod tests {
     fn clone() {
         let registry = DropRegistry::default();
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 0,
-                dropped: 0
-            }
-        );
+        assert_drop_stats!(registry, { created: 0, dropped: 0 });
 
         let guard = registry.new_guard_for(42);
         let guard_id = guard.id();
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 1,
-                dropped: 0
-            }
-        );
+        assert_drop_stats!(registry, { created: 1, dropped: 0 });
 
         let cloned_guard = guard.clone();
         let cloned_guard_id = cloned_guard.id();
 
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 2,
-                dropped: 0
-            }
-        );
+        assert_drop_stats!(registry, { created: 2, dropped: 0 });
 
         std::mem::drop(guard);
 
         assert_drop!(registry, guard_id);
-        assert!(!registry.is_dropped(cloned_guard_id));
-
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 2,
-                dropped: 1
-            }
-        );
+        assert_no_drop!(registry, cloned_guard_id);
+        assert_drop_stats!(registry, { created: 2, dropped: 1 });
 
         std::mem::drop(cloned_guard);
 
         assert_drop!(registry, guard_id);
-        assert!(registry.is_dropped(cloned_guard_id));
-
-        assert_eq!(
-            registry.stats(),
-            DropStatistics {
-                created: 2,
-                dropped: 2
-            }
-        );
+        assert_drop!(registry, cloned_guard_id);
+        assert_drop_stats!(registry, { created: 2, dropped: 2 });
     }
 
     #[test]
